@@ -2,8 +2,12 @@ from .TextKit import cprint
 from .BackgroundKit import bgcolor
 from .ColorKit import *
 
+#for windows support
+import os
+os.system('')
+
 def version():
-    print('Current Version: 0.1')
+    print('Current Version: 0.1.2')
 
 def colors():
     availableColors=[
